"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CRC8 = void 0;
const qcloud_iotexplorer_appdev_sdk_1 = require("qcloud-iotexplorer-appdev-sdk");
const { byteUtil } = qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils;
class CRC8 {
    constructor() {
        this.crcTable = new Int32Array(256);
        this.CRC_POLYNOM = 0x8c;
        this.CRC_INITIAL = 0x00;
        for (let dividend = 0; dividend < 256; dividend++) {
            let remainder = dividend; // << 8;
            for (let bit = 0; bit < 8; ++bit) {
                if ((remainder & 0x01) !== 0)
                    remainder = (remainder >>> 1) ^ this.CRC_POLYNOM;
                else
                    remainder >>>= 1;
            }
            this.crcTable[dividend] = remainder;
        }
        // eslint-disable-next-line no-multi-assign
        this.value = this.init = this.CRC_INITIAL;
    }
    updateValue(buffer, offset, len) {
        for (let i = 0; i < len; i++) {
            const data = buffer[offset + i] ^ this.value;
            this.value = (this.crcTable[data & 0xff] ^ (this.value << 8));
        }
    }
    /**
     * Updates the current checksum with the specified array of bytes.
     * Equivalent to calling <code>update(buffer, 0, buffer.length)</code>.
     *
     * @param buffer the byte array to update the checksum with
     */
    update(buffer) {
        if (buffer instanceof Int8Array) {
            this.updateValue(buffer, 0, buffer.length);
        }
        else if (typeof buffer === 'number') {
            this.update(new Int8Array([byteUtil.convertNumberToByte(buffer)]));
        }
    }
    getValue() {
        return this.value & 0xff;
    }
    reset() {
        this.value = this.init;
    }
}
exports.CRC8 = CRC8;
//# sourceMappingURL=CRC8.js.map