"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.collectModuleLog = void 0;
const tslib_1 = require("tslib");
/**
 * @description 收集模组的日志 */
const qcloud_iotexplorer_appdev_sdk_1 = require("qcloud-iotexplorer-appdev-sdk");
const constants_1 = require("../constants");
const UdpServer_1 = require("./UdpServer");
const wxApis_1 = tslib_1.__importDefault(require("./wxApis"));
const util_1 = require("./util");
const MODULE_REPORT_AP_SSID = 'ESP-LOG-QUERY';
const MODULE_REPORT_AP_PASSWORD = '86013388';
const MODULE_REPORT_AP_UDP_ADDRESS = '192.168.4.1';
const MODULE_REPORT_AP_UDP_PORT = '9876';
const MODULE_REPORT_AP_TIMEOUT = 1000 * 60;
const MODULE_REPORT_RETRY_TIMES = 12;
const collectModuleLogInternal = async ({ reporter, sdk, }) => {
    try {
        const startTime = Date.now();
        reporter.info("MODULE_REPORT_START" /* WifiConfStepCode.MODULE_REPORT_START */);
        const isAndroid = (0, util_1.checkIsAndroid)();
        if (!isAndroid) {
            qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.tips.showLoading('收集日志中');
        }
        reporter.info("MODULE_REPORT_CONNECT_WIFI_START" /* WifiConfStepCode.MODULE_REPORT_CONNECT_WIFI_START */, {
            // 立即上报
            urgent: true,
        });
        await wxApis_1.default.startWifi();
        await wxApis_1.default.connectWifi({
            SSID: MODULE_REPORT_AP_SSID,
            password: MODULE_REPORT_AP_PASSWORD,
        });
        const { wifi } = await wxApis_1.default.getConnectedWifi();
        if (wifi.SSID !== MODULE_REPORT_AP_SSID) {
            throw { code: 'WIFI_RECONNECT_FAIL' };
        }
        // Android下小程序连WiFi时有一个“微信连WiFi”的toast
        // 延迟到连WiFi成功后才显示收集日志的loading
        if (isAndroid) {
            qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.tips.showLoading('收集日志中');
        }
        reporter.info("MODULE_REPORT_CONNECT_WIFI_SUCCESS" /* WifiConfStepCode.MODULE_REPORT_CONNECT_WIFI_SUCCESS */, {
            timeCost: Date.now() - startTime,
            shouldStopTemp: true,
        });
        try {
            const udpServer = new UdpServer_1.UdpServer({
                address: MODULE_REPORT_AP_UDP_ADDRESS,
                port: MODULE_REPORT_AP_UDP_PORT,
                reporter,
                // 制定重试的规则，比默认的多一些
                retryTime: MODULE_REPORT_RETRY_TIMES,
                retryGap: MODULE_REPORT_AP_TIMEOUT / MODULE_REPORT_RETRY_TIMES,
                messageNoParse: true,
                sdk,
            });
            // 1. 建立连接
            const onErrorPromise = qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.genPromise();
            const onProgressErrorPromise = qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.genPromise();
            udpServer.onError(errMsg => onErrorPromise.reject({
                code: 'MODULE_REPORT_COMMUNICATE_AP_ERROR',
                detail: { errMsg },
            }));
            udpServer.onProgressError(message => onProgressErrorPromise.reject({
                code: 'MODULE_REPORT_COMMUNICATE_AP_ERROR',
                detail: message,
            }));
            reporter.info("MODULE_REPORT_COMMUNICATE_AP_START" /* WifiConfStepCode.MODULE_REPORT_COMMUNICATE_AP_START */);
            const response = await udpServer.send({
                cmdType: 3,
            });
            reporter.info("MODULE_REPORT_COMMUNICATE_AP_SUCCESS" /* WifiConfStepCode.MODULE_REPORT_COMMUNICATE_AP_SUCCESS */, {
                moudleDetail: response,
                timeCost: Date.now() - startTime,
            });
        }
        catch (error) {
            reporter.error('MODULE_REPORT_COMMUNICATE_AP_ERROR', {
                error,
            });
        }
    }
    finally {
        qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.tips.hideLoading();
        await qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.delay(2000);
        reporter.info("MODULE_REPORT_COMMUNICATE_END" /* WifiConfStepCode.MODULE_REPORT_COMMUNICATE_END */, {
            shouldStopTemp: false,
        });
    }
};
const collectModuleLog = async ({ reporter, doCollectModuleLog = collectModuleLogInternal, timeout = MODULE_REPORT_AP_TIMEOUT, sdk, }) => {
    try {
        const onTimeoutPromise = qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.genPromise();
        // 超时失败
        setTimeout(() => {
            onTimeoutPromise.reject({
                code: 'MODULE_REPORT_TIMEOUT',
            });
        }, timeout);
        await Promise.race([
            onTimeoutPromise.promise,
            doCollectModuleLog({ reporter, sdk }),
        ]);
        qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.tips.showModal({
            title: '上报设备端日志成功',
            content: '收集成功，已上报给工程师处理',
            confirmText: '我知道了',
            showCancel: false,
        });
        return true;
    }
    catch (error) {
        const errCode = error && (error.errCode || error.code);
        if (errCode) {
            if (errCode in constants_1.WifiConfErrorMsg) {
                error.uiMsg = constants_1.WifiConfErrorMsg[errCode];
            }
            else if (errCode in constants_1.WifiConfErrorMsg) {
                error.uiMsg = constants_1.WifiConfErrorMsg[errCode];
            }
        }
        reporter.error('MODULE_REPORT_FAIL', { error });
        qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.tips.showModal({
            title: '上报设备端日志失败',
            content: error.uiMsg || constants_1.WifiConfErrorMsg.MODULE_REPORT_ERROR,
            confirmText: '我知道了',
            showCancel: false,
        });
        return false;
    }
};
exports.collectModuleLog = collectModuleLog;
//# sourceMappingURL=moduleLog.js.map