"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.reconnectWifi = void 0;
const tslib_1 = require("tslib");
const qcloud_iotexplorer_appdev_sdk_1 = require("qcloud-iotexplorer-appdev-sdk");
const constants_1 = require("../constants");
const connectWifiBase_1 = require("./connectWifiBase");
const wxApis_1 = tslib_1.__importDefault(require("./wxApis"));
const util_1 = require("./util");
const { delay } = qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils;
const onNetworkStatusChange = () => new Promise((resolve, reject) => {
    // 加个超时时间
    // 5s的由来是因为设备热点是5s后断开，这个是确定的值，可以做成参数配置 TODO
    const startTime = Date.now();
    console.log('onNetworkStatusChange', startTime);
    const timeInt = setTimeout(() => {
        wxApis_1.default.offNetworkStatusChange(statusChange);
        wxApis_1.default.getNetworkType().then((res) => {
            console.log('getNetworkType', res);
            if (res.networkType === 'none') {
                reject({
                    code: 'BUSINESS_WIFI_RECONNECT_STATE_CHANGE_TIMEOUT',
                });
            }
            else {
                resolve(Object.assign(Object.assign({}, res), { timeCost: Date.now() - startTime }));
            }
        });
        // 8秒是经验值
    }, 5000 + 8000);
    const statusChange = (res) => {
        const { isConnected } = res;
        console.log('onNetWorkStatusChange', res);
        if (isConnected) {
            clearTimeout(timeInt);
            wxApis_1.default.offNetworkStatusChange(statusChange);
            // 至少 5s吧，不然可能会网络cgi发送失败
            const timeGap = 5000 - (Date.now() - startTime);
            console.log('onNetWorkStatusChange is connected', timeGap);
            if (timeGap <= 0) {
                resolve(Object.assign(Object.assign({}, res), { timeCost: Date.now() - startTime }));
            }
            else {
                delay(timeGap).then(() => {
                    resolve(Object.assign(Object.assign({}, res), { timeCost: Date.now() - startTime }));
                });
            }
        }
    };
    wxApis_1.default.onNetworkStatusChange(statusChange);
});
/**
 * 目前重连回网络有三种情况
 * 1.必须连回家庭wifi(useTargetWifi=true)，对应 protoVersion=3.0 同一udp通信
 * 2.等待系统切换网络，13s后依然没网，wx.connectWifi连接家庭wifi
 * 3.兼容鸿蒙调用connectWifi的错误，只能一直等待系统切换网络
 */
const reconnectWifi = async (wifiInfo, { onProgress, 
// 是否允许出错，如果出错的话，自动继续用系统底层的网络连接，比如4G，因为小程序没有提供是否支持4G的判断，所以只能无脑忽略出错
ignoreError = false, useTargetWifi = false, }) => {
    const isIOS = (0, util_1.checkIsIOS)();
    const startConnectWifi = Date.now();
    try {
        onProgress({
            code: "SOFTAP_RECONNECT_TARGET_WIFI_START" /* WifiConfStepCode.SOFTAP_RECONNECT_TARGET_WIFI_START */,
            reportEvents: ['重连wifi'],
        });
        // 防止没有启动
        let connectStatus;
        // 主动去连接家庭wifi
        if (useTargetWifi) {
            await (0, connectWifiBase_1.connectWifiBase)(wifiInfo);
            onProgress({
                code: "SOFTAP_RECONNECT_TARGET_WIFI_SUCCESS" /* WifiConfStepCode.SOFTAP_RECONNECT_TARGET_WIFI_SUCCESS */,
                detail: {
                    timeCost: Date.now() - startConnectWifi,
                },
                reportEvents: ['重连wifi'],
            });
        }
        else {
            try {
                // 延迟去连wifi，因为新的ios版本，会在系统还有连接Wi-Fi流程中的时候小程序发起的连接必现 无法连接 的弹窗。因为设备热点会断开，系统会有一次自动切Wi-Fi的
                connectStatus = await onNetworkStatusChange();
                // 直接就成功了，不需要再连接Wi-Fi了
                onProgress({
                    code: "SOFTAP_RECONNECT_TARGET_WIFI_SUCCESS" /* WifiConfStepCode.SOFTAP_RECONNECT_TARGET_WIFI_SUCCESS */,
                    detail: {
                        connectStatus,
                        type: 'SOFTAP_RECONNECT_TARGET_WIFI_USE_DEFAULT',
                    },
                    reportEvents: ['重连wifi'],
                });
            }
            catch (e) {
                const isHuaWei = (0, util_1.checkIsHuaWei)();
                if (!isHuaWei) {
                    console.error(e);
                    await (0, connectWifiBase_1.connectWifiBase)(wifiInfo);
                    onProgress({
                        code: "SOFTAP_RECONNECT_TARGET_WIFI_SUCCESS" /* WifiConfStepCode.SOFTAP_RECONNECT_TARGET_WIFI_SUCCESS */,
                        detail: {
                            timeCost: Date.now() - startConnectWifi,
                        },
                        reportEvents: ['重连wifi'],
                    });
                }
            }
        }
    }
    catch (error) {
        console.error(error);
        const isConfirm = await qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.tips.confirm(`手机连接目标Wi-Fi“${wifiInfo.SSID}”失败，请手动切换到能够正常访问的网络环境(移动网络或者WI-FI)后继续配网操作`, '', {
            confirmText: '继续',
            confirmColor: qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.constants.themeColorMap.primary,
            cancelText: '取消',
            cancelColor: qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.constants.themeColorMap.danger,
            enforce: true,
        });
        if (!isConfirm && !ignoreError) {
            return Promise.reject(Object.assign(Object.assign({}, error), { code: 'BUSINESS_WIFI_RECONNECT_FAIL' }));
        }
        onProgress({
            code: "SOFTAP_RECONNECT_TARGET_WIFI_SUCCESS" /* WifiConfStepCode.SOFTAP_RECONNECT_TARGET_WIFI_SUCCESS */,
            detail: {
                ignoreError,
                timeCost: Date.now() - startConnectWifi,
            },
        });
    }
    finally {
        isIOS && qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.tips.hideLoading();
    }
};
exports.reconnectWifi = reconnectWifi;
//# sourceMappingURL=reconnectWifi.js.map