"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TouchAES = void 0;
const qcloud_iotexplorer_appdev_sdk_1 = require("qcloud-iotexplorer-appdev-sdk");
const { CryptoJS } = qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils;
class TouchAES {
    constructor(key, iv, transformationMode, transformationPadding) {
        this.TRANSFORMATION_MODE_DEFAULT = CryptoJS.mode.ECB;
        this.TRANSFORMATION_PADDING_DEFAULT = CryptoJS.pad.Pkcs7;
        this.mKey = key;
        this.mIV = iv;
        this.mTransformationMode = transformationMode || this.TRANSFORMATION_MODE_DEFAULT;
        this.mTransformationPadding = transformationPadding || this.TRANSFORMATION_PADDING_DEFAULT;
    }
    encrypt(content) {
        const key = CryptoJS.enc.Utf8.parse(this.mKey);
        const iv = CryptoJS.enc.Utf8.parse(this.mIV);
        const encrypted = CryptoJS.AES.encrypt(content, key, {
            iv, mode: this.mTransformationMode, padding: this.mTransformationPadding,
        });
        console.log(`encrypted: ${encrypted}`);
        return encrypted;
    }
    decrypt(content) {
        const key = CryptoJS.enc.Utf8.parse(this.mKey);
        const iv = CryptoJS.enc.Utf8.parse(this.mIV);
        const encryptedHexStr = CryptoJS.enc.Hex.parse(content);
        const encryptedBase64Str = CryptoJS.enc.Base64.stringify(encryptedHexStr);
        const decrypted = CryptoJS.AES.decrypt(encryptedBase64Str, key, {
            iv,
            mode: this.mTransformationMode,
            padding: this.mTransformationPadding,
        });
        console.log(`decrypted: ${decrypted.toString(CryptoJS.enc.Utf8)}`);
        return decrypted;
    }
}
exports.TouchAES = TouchAES;
//# sourceMappingURL=TouchAES.js.map