"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryRequest = void 0;
const qcloud_iotexplorer_appdev_sdk_1 = require("qcloud-iotexplorer-appdev-sdk");
const tryRequest = async (tryingFn, { reporter }) => {
    try {
        return await tryingFn();
    }
    catch (err) {
        reporter.info('wificonf-try-request-fail', { error: err });
        if (err) {
            // 网络请求失败
            if (err.errMsg && /request:fail/.test(err.errMsg)) {
                const isConfirm = await qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.tips.confirm('手机无法正常访问网络', '尝试更换手机Wi-Fi网络或切换到移动信号后重试', {
                    confirmText: '重试',
                    confirmColor: qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.constants.themeColorMap.primary,
                    cancelText: '取消配网',
                    cancelColor: qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.constants.themeColorMap.danger,
                });
                if (isConfirm) {
                    reporter.info('wificonf-retry-request');
                    return (0, exports.tryRequest)(tryingFn, { reporter });
                }
                else {
                    return Promise.reject(err);
                }
            }
            else {
                const isConfirm = await qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.tips.confirm(qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.tips.getErrorMsg(err), '', {
                    confirmText: '重试',
                    confirmColor: qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.constants.themeColorMap.primary,
                    cancelText: '取消',
                    cancelColor: qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.constants.themeColorMap.danger,
                });
                if (isConfirm) {
                    reporter.info('wificonf-retry-request');
                    return (0, exports.tryRequest)(tryingFn, { reporter });
                }
            }
        }
        return Promise.reject(err);
    }
};
exports.tryRequest = tryRequest;
//# sourceMappingURL=tryRequest.js.map