"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UDPSocket = void 0;
/**
 * @description airkiss使用的udp通道，先不做统一了
 */
const qcloud_iotexplorer_appdev_sdk_1 = require("qcloud-iotexplorer-appdev-sdk");
class UDPSocket extends qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.EventEmitter {
    constructor(port) {
        super();
        this.isClose = false;
        this.destroy = qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.noop;
        this.socket = wx.createUDPSocket();
        console.log('udp socket bind on port', port || 'random');
        try {
            this.socket.bind(port);
        }
        catch (err) {
            this.emit('error', err);
        }
        const onClose = e => this.emit('close', e);
        const onError = e => this.emit('error', e);
        const onMessage = e => this.emit('message', e);
        const onListening = e => this.emit('listening', e);
        this.socket.onClose(e => onClose(e));
        this.socket.onError(e => onError(e));
        this.socket.onMessage(e => onMessage(e));
        this.socket.onListening(onListening);
        this.destroy = () => {
            console.log('udp client destroy');
            this.isClose = true;
            this.socket.offClose(onClose);
            this.socket.offError(onError);
            this.socket.offMessage(onMessage);
            this.socket.offListening(onListening);
            this.socket.close();
        };
    }
    async sendData({ address, port, message, offset, length, timeDelay, }) {
        await new Promise((resolve, reject) => {
            try {
                this.socket.send({
                    address,
                    port,
                    message,
                    offset,
                    length,
                });
                resolve();
            }
            catch (err) {
                reject(err);
            }
        });
        if (timeDelay) {
            await qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.delay(timeDelay);
        }
    }
    sendDataSideBySide({ address, port, data = [], // data是个数组
    offset, length, timeDelay, callback, }) {
        if (length <= 0 || this.isClose) {
            return callback();
        }
        setTimeout(() => {
            this.socket.send({
                address,
                port,
                message: data[offset],
            });
            const offsetNext = Math.min(data.length - 1, offset + 1);
            const countNext = offsetNext >= data.length ? 0 : length - 1;
            // console.log('send----data---', offsetNext, countNext, address, port);
            this.sendDataSideBySide({ address, port, data, offset: offsetNext, length: countNext, timeDelay, callback });
        }, timeDelay);
    }
}
exports.UDPSocket = UDPSocket;
//# sourceMappingURL=UDPSocket.js.map