"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UDPSocketServer = void 0;
const qcloud_iotexplorer_appdev_sdk_1 = require("qcloud-iotexplorer-appdev-sdk");
const util_1 = require("../util");
class UDPSocketServer extends qcloud_iotexplorer_appdev_sdk_1.AppDevSdk.utils.EventEmitter {
    constructor(socket, socketTimeout, correctLen) {
        super();
        this.TAG = 'UDPSocketServer';
        this.msgHandler = util_1.noop;
        this.mSocket = socket;
        this.isClose = false;
        // 监听onclose的状态，关闭了就不再抓包
        this.mSocket.onClose(() => {
            this.interrupt();
        });
        this.mTimeout = socketTimeout;
        if (correctLen) {
            this.mCorrectLen = correctLen;
        }
    }
    startServer() {
        this.handlerTimeout(this.mTimeout);
        this.onListening();
        this.onMessage(this.mCorrectLen);
    }
    handlerTimeout(mSocketTimeout) {
        this.mSocketTimeoutTimer = setTimeout(() => {
            this.emit('timeout');
            this.interrupt();
        }, mSocketTimeout);
    }
    onMessage(len) {
        this.msgHandler = (res) => {
            if (this.isClose)
                return;
            console.log(this.TAG, 'recieveMsg', res);
            this.emit('recieveMsg', res);
            // 先简单校验一下长度
            if (!len || (len && res.remoteInfo.size === len)) {
                this.emit('recieveCorrectMsg', res);
            }
            else {
                console.log(this.TAG, 'received len is different from specific len');
            }
        };
        this.mSocket.onMessage(this.msgHandler);
    }
    onListening() {
        this.mSocket.onListening((res) => {
            if (this.isClose)
                return;
            this.emit('recieveMsg', res);
            console.log(this.TAG, 'onListening', res);
        });
    }
    interrupt() {
        console.log(this.TAG, 'USPSocketServer is interrupt');
        this.mSocket.offMessage(this.msgHandler);
        this.close();
    }
    // 关闭
    close() {
        this.isClose = true;
    }
}
exports.UDPSocketServer = UDPSocketServer;
//# sourceMappingURL=UDPSocketServer.js.map