import { AppDevSdk } from 'qcloud-iotexplorer-appdev-sdk';
import { pollRequest, tryRequest } from '../utils';
const getBindState = (sdk, token) => sdk.requestApi('AppGetDeviceBindTokenState', { Token: token }, { isTokenApi: true });
const getMultiBindState = (sdk, token) => sdk.requestApi('AppGetMultiDeviceBindTokenState', { Token: token }, { isTokenApi: true });
export async function queryTokenStateAndBind({ token, productId, deviceName, familyId, roomId, onProgress, sdk, skipBind = false, // 只校验token，不执行绑定
newTokenVersion = false, // 是否替无感配网方案
 }) {
    var _a, _b, _c, _d, _e;
    // 3.0策略（前端替换api、设备端无需改动,不过需在小程序用新api生成token）
    const protoVersion = newTokenVersion ? 'v3.0' : 'v2.0';
    const queryStartTime = Date.now();
    onProgress({
        code: "BUSINESS_QUERY_TOKEN_STATE_START" /* WifiConfStepCode.BUSINESS_QUERY_TOKEN_STATE_START */,
        detail: {
            data: { Token: token },
        },
        reportEvents: [
            'queryToken',
        ],
    });
    try {
        console.log('protoVersion ', protoVersion, 'newTokenVersion', newTokenVersion);
        if (newTokenVersion) {
            const res = await pollRequest({
                request: () => getMultiBindState(sdk, token),
                checkResp(resp) {
                    var _a, _b, _c;
                    console.log('checkrespv3', resp);
                    const { Data } = resp;
                    // Data = [{
                    //   ErrCode: 'InvalidParameterValue.TokenNotBind',
                    //   ErrMsg: '设备已被用户 (family:pieceone的连连生活，user：Wx_ 6973137068)绑定',
                    // }];
                    if (Data && Array.isArray(Data)) {
                        if ((_a = Data[0]) === null || _a === void 0 ? void 0 : _a.ErrCode) {
                            throw {
                                code: "QUERY_TOKEN_RESULT_ERROR" /* WifiConfStepCode.QUERY_TOKEN_RESULT_ERROR */,
                                msg: ((_b = Data[0]) === null || _b === void 0 ? void 0 : _b.ErrMsg) || '查询设备连接云端状态失败',
                            };
                        }
                        // 不强校验设备信息、目前前端逻辑一个token只会给到一个设备 背景：有些客户传给小程序的productId/deviceName可能不对，这里增加容
                        return ((_c = Data[0]) === null || _c === void 0 ? void 0 : _c.State) === 2;
                    }
                    return false;
                },
                reporter: sdk.reporter,
                maxIgnoreErrorTimes: 15,
            });
            // 最后的设备信息以绑定token的为准、同时也兼容了设备端没传的情况
            const { Data } = res;
            if (Data === null || Data === void 0 ? void 0 : Data[0]) {
                try {
                    // 存在设备上报信息和实际配网设备不一致的情况，先上报一个状态码，但不做强校验
                    if (productId !== ((_a = Data[0]) === null || _a === void 0 ? void 0 : _a.ProductId) || deviceName !== ((_b = Data[0]) === null || _b === void 0 ? void 0 : _b.DeviceName)) {
                        (_c = sdk === null || sdk === void 0 ? void 0 : sdk.reporter) === null || _c === void 0 ? void 0 : _c.info('QUERY_TOKEN_DEVICE_INFO_INCORRECT', {
                            data: Object.assign({ productIdFromDeviceReport: productId, deviceNameFromDeviceReport: deviceName }, Data[0]),
                        });
                    }
                }
                catch (err) {
                    console.error(err);
                }
                productId = (_d = Data[0]) === null || _d === void 0 ? void 0 : _d.ProductId;
                deviceName = (_e = Data[0]) === null || _e === void 0 ? void 0 : _e.DeviceName;
            }
        }
        else {
            const res = await pollRequest({
                request: () => getBindState(sdk, token),
                checkResp(resp) {
                    const { State } = resp;
                    return State === 2;
                },
                reporter: sdk.reporter,
                maxIgnoreErrorTimes: 15,
            });
            // 旧协议也兼容下只传了productid过来的情况
            if (!productId || !deviceName) {
                const { ProductId, DeviceName } = res;
                productId = ProductId;
                deviceName = DeviceName;
                if (!ProductId) {
                    throw {
                        code: 'BUSINESS_QUERY_PRODUCTID_NOT_FOUND',
                    };
                }
            }
        }
    }
    catch (err) {
        if (err && err.code === 'POLL_REQUEST_TIMEOUT') {
            throw {
                code: 'BUSINESS_QUERY_BIND_TOKEN_TIMEOUT',
            };
        }
        else {
            throw {
                code: 'BUSINESS_QUERY_BIND_TOKEN_FAIL',
                detail: err,
                msg: AppDevSdk.utils.tips.getErrorMsg(err),
                reqId: err === null || err === void 0 ? void 0 : err.reqId,
            };
        }
    }
    onProgress({
        code: "BUSINESS_QUERY_TOKEN_STATE_SUCCESS" /* WifiConfStepCode.BUSINESS_QUERY_TOKEN_STATE_SUCCESS */,
        detail: {
            protoVersion,
            timeCost: Date.now() - queryStartTime,
        },
        reportEvents: [
            'queryToken',
        ],
    });
    console.log('new tokenVersion query token come to return');
    if (skipBind || newTokenVersion) {
        return {
            productId,
            deviceName,
        };
    }
    onProgress({
        code: "BUSINESS_ADD_DEVICE_START" /* WifiConfStepCode.BUSINESS_ADD_DEVICE_START */,
        detail: {
            data: {
                Token: token,
                ProductId: productId,
                DeviceName: deviceName,
                FamilyId: familyId,
                RoomId: roomId,
            },
            protoVersion,
        },
        reportEvents: [
            'addDevice',
        ],
    });
    try {
        await tryRequest(() => sdk.requestApi('AppTokenBindDeviceFamily', {
            FamilyId: familyId,
            ProductId: productId,
            DeviceName: deviceName,
            Token: token,
            RoomId: roomId,
        }, { isTokenApi: true }), { reporter: sdk.reporter });
    }
    catch (err) {
        return Promise.reject({
            code: 'BUSINESS_ADD_DEVICE_FAIL',
            detail: err,
            msg: AppDevSdk.utils.tips.getErrorMsg(err),
            reqId: err.reqId,
        });
    }
    onProgress({
        code: "BUSINESS_ADD_DEVICE_SUCCESS" /* WifiConfStepCode.BUSINESS_ADD_DEVICE_SUCCESS */,
    });
    return {
        productId,
        deviceName,
    };
}
//# sourceMappingURL=queryTokenStateAndBind.js.map