import { AppDevSdk } from 'qcloud-iotexplorer-appdev-sdk';
import { tryRequest } from './tryRequest';
const DEFAULT_MAX_QUERY_TIMES = 20;
const DEFAULT_MAX_IGNORE_ERROR_TIMES = 20;
const DEFAULT_QUERY_GAP = 2000;
const resolveParams = (params) => {
    let maxQueryTimes = params.maxQueryTimes || DEFAULT_MAX_QUERY_TIMES;
    let maxIgnoreErrorTimes = params.maxIgnoreErrorTimes || DEFAULT_MAX_IGNORE_ERROR_TIMES;
    const queryGap = params.queryGap || DEFAULT_QUERY_GAP;
    maxQueryTimes = Math.max(maxQueryTimes, maxIgnoreErrorTimes);
    maxIgnoreErrorTimes = Math.min(maxQueryTimes, maxIgnoreErrorTimes);
    if (typeof params.request !== 'function') {
        throw new Error('PollRequestProps request must be a function');
    }
    return Object.assign(Object.assign({}, params), { maxQueryTimes,
        maxIgnoreErrorTimes,
        queryGap });
};
export const pollRequest = async function (params) {
    const { maxQueryTimes, maxIgnoreErrorTimes, queryGap, request, checkResp, reporter, } = resolveParams(params);
    let retryTime = 0;
    let errorTime = 0;
    let result;
    while (true) {
        AppDevSdk.utils.logger.debug('poll request retryTime', retryTime);
        AppDevSdk.utils.logger.debug('poll request errorTime', errorTime);
        console.log('poll request time', retryTime, errorTime);
        if (errorTime < maxIgnoreErrorTimes) {
            try {
                result = await request();
                retryTime++;
            }
            catch (e) {
                errorTime++;
                console.error('ignore request method error', e);
                await AppDevSdk.utils.delay(queryGap);
                continue;
            }
        }
        else {
            result = await tryRequest(() => request(), { reporter });
            retryTime++;
        }
        // 满足条件，终止轮询
        if (result && (typeof checkResp !== 'function' || checkResp(result) === true)) {
            break;
        }
        // 超过次数上限
        if (retryTime >= maxQueryTimes) {
            throw {
                code: 'POLL_REQUEST_TIMEOUT',
            };
        }
        await AppDevSdk.utils.delay(queryGap);
    }
    return result;
};
//# sourceMappingURL=pollRequest.js.map