import { AppDevSdk } from 'qcloud-iotexplorer-appdev-sdk';
import { compareVersion } from '../util';
const delayPromise = (time) => new Promise((resolve) => {
    setTimeout(() => {
        resolve();
    }, time);
});
export class UDPSocketClient extends AppDevSdk.utils.EventEmitter {
    // 队列运行状态
    constructor(port) {
        super();
        this.TAG = 'UDPSocketClient';
        this.dataQueue = {};
        // 队列
        this.queueExcuteState = {};
        if (this.checkIsSupport()) {
            this.mSocket = wx.createUDPSocket();
            this.mSocket.bind(port);
            this.isClose = false;
            // 监听onclose的状态，关闭了就不再抓包
            this.mSocket.onClose(() => {
                this.isClose = true;
            });
            this.errorHandler = (msg) => {
                this.emit('udpSocketError', msg);
            };
            this.mSocket.onError(this.errorHandler);
        }
    }
    checkIsSupport() {
        const version = wx.getSystemInfoSync().SDKVersion;
        if (compareVersion(version, '2.7.0') < 0) {
            this.emit('udpSocketError', '当前微信版本过低，无法使用udpsocket的功能，请升级到最新微信版本后重试。');
            return false;
        }
        else {
            return true;
        }
    }
    // 中断
    interrupt() {
        console.log(this.TAG, 'USPSocketClient is interrupt');
        this.close();
    }
    // 关闭
    close() {
        this.isClose = true;
        if (this.mSocket) {
            this.mSocket.offError(this.errorHandler);
            this.mSocket.close();
            this.mSocket = null;
        }
    }
    sendDataSideBySide(data, offset = 0, count, targetIp, targetPort, interval, callback) {
        if (count === 1 || this.isClose) {
            // console.log('send----data---', offset, targetIp, targetPort);
            !this.isClose && this.mSocket.send({
                address: targetIp,
                port: targetPort,
                message: data[offset],
            });
            return callback();
        }
        setTimeout(() => {
            const offsetNext = Math.min(data.length - 1, offset + 1);
            const countNext = offsetNext >= data.length - 1 ? 1 : count - 1;
            // console.log('send----data---', offsetNext, countNext, targetIp, targetPort);
            !this.isClose && this.mSocket.send({
                address: targetIp,
                port: targetPort,
                message: data[offset],
            });
            this.sendDataSideBySide(data, offsetNext, countNext, targetIp, targetPort, interval, callback);
        }, interval);
    }
    /**
       * send the data by UDP
       *
       * @param data       the data to be sent
       * @param offset     the offset which data to be sent
       * @param count      the count of the data
       * @param targetPort the port of target
       * @param interval   the milliseconds to between each UDP sent
       */
    async sendData(data, offset = 0, count, targetIp, targetPort, interval) {
        // eslint-disable-next-line eqeqeq
        if (!data || data.length <= 0) {
            console.log(this.TAG, 'sendData(): data == null or length <= 0');
            return;
        }
        if (this.isClose) {
            console.log(this.TAG, 'udpsocket is close');
            return;
        }
        for (let i = offset; i < Math.min(offset + count, data.length); i++) {
            console.log('UDPSocketClient send', {
                address: targetIp,
                port: targetPort,
                message: data[i],
            });
            this.mSocket.send({
                address: targetIp,
                port: targetPort,
                message: data[i],
            });
            await delayPromise();
        }
        // 最后才delay
        await AppDevSdk.utils.delay(interval);
    }
}
//# sourceMappingURL=UDPSocketClient.js.map