import { AppDevSdk } from 'qcloud-iotexplorer-appdev-sdk';
export const { noop } = AppDevSdk.utils;
export function compareVersion(_v1, _v2) {
    const v1 = _v1.split('.');
    const v2 = _v2.split('.');
    const len = Math.max(v1.length, v2.length);
    while (v1.length < len) {
        v1.push('0');
    }
    while (v2.length < len) {
        v2.push('0');
    }
    for (let i = 0; i < len; i++) {
        const num1 = parseInt(v1[i]);
        const num2 = parseInt(v2[i]);
        if (num1 > num2) {
            return 1;
        }
        else if (num1 < num2) {
            return -1;
        }
    }
    return 0;
}
/**
 * parse InetAddress
 *
 * @param inetAddrBytes
 * @return
 */
export function parseInetAddr(inetAddrBytes, offset, count) {
    let sb = '';
    for (let i = 0; i < count; i++) {
        sb += String(inetAddrBytes[offset + i] & 0xff);
        if (i !== count - 1) {
            sb += '.';
        }
    }
    return sb;
}
/**
 * format InetAddress to bytes
 *
 * @param[String] ipAddress
 * @return
 */
export function formatInetAddr(ipAddress = '') {
    const ipArray = ipAddress.split('.');
    const ipBytes = new Int8Array(ipArray.length);
    for (let i = 0; i < ipArray.length; i++) {
        const ipSegment = parseInt(ipArray[i]);
        // https://www.xuebuyuan.com/zh-hant/1898388.html
        ipBytes[i] = ipSegment > 127 ? ipSegment - 256 : ipSegment;
    }
    return ipBytes;
}
/**
 * format InetAddress to int
 *
 * @param[String] ipAddress
 * @return
 */
export function ip2int(s) {
    const sp = formatInetAddr(s);
    return (sp[0] & 255) * 0x1000000 + (sp[1] & 255) * 0x10000 + (sp[2] & 255) * 0x100 + (sp[3] & 255);
}
/**
 * format int to ip
 *
 * @param[String] ipAddress
 * @return
 */
export function int2ip(n) {
    return `${(n >> 24) & 255}.${(n >> 16) & 255}.${(n >> 8) & 255}.${n & 255}`;
}
/**
 * format intip to byte
 *
 * @param[String] ipAddress
 * @return
 */
export function intIp2byte(__in) {
    const out = [0, 0, 0, 0];
    out[0] = ((((__in >> 24) & 255) | 0));
    out[1] = ((((__in >> 16) & 255) | 0));
    out[2] = ((((__in >> 8) & 255) | 0));
    out[3] = (((__in & 255) | 0));
    return out;
}
export function arrayFill(array, value) {
    for (let i = 0; i < array.length; i++) {
        array[i] = value;
    }
}
export const checkIsAndroid = () => wx.getSystemInfoSync().platform.indexOf('android') > -1;
export const androidLaterThan7022 = () => {
    const isAndroid = checkIsAndroid();
    const highVersion = compareVersion(getWxVersion(), '7.0.22') >= 0;
    return isAndroid && highVersion;
};
export const checkIsIOS = () => wx.getSystemInfoSync().platform.indexOf('ios') > -1;
export const checkIsHuaWei = () => wx.getSystemInfoSync().brand.indexOf('HUAWEI') > -1;
export const getWxVersion = () => wx.getSystemInfoSync().version;
//# sourceMappingURL=util.js.map